# TOPSIS Package

## Overview
This package implements the **TOPSIS (Technique for Order of Preference by Similarity to Ideal Solution)** method, which is commonly used for decision-making in multi-criteria problems.

## Installation
You can install the package via `pip`:

```bash
pip install 102203166-topsis-stuti
